@@ -7,8 +7,14 @@
 # @License: BSD 3-clause (http://www.opensource.org/licenses/BSD-3-Clause)
 
 
-__all__ = ['CluError', 'CluNotImplemented', 'CluWarning',
-           'CluDeprecationWarning', 'CommandError', 'CommandParserError']
+__all__ = [
+    "CluError",
+    "CluNotImplemented",
+    "CluWarning",
+    "CluDeprecationWarning",
+    "CommandError",
+    "CommandParserError",
+]
 
 
 class CluError(Exception):
@@ -16,8 +22,7 @@ class CluError(Exception):
 
     def __init__(self, message=None):
 
-        message = 'There has been an error' \
-            if not message else message
+        message = "There has been an error" if not message else message
 
         super(CluError, self).__init__(message)
 
@@ -27,7 +32,7 @@ class CluNotImplemented(CluError):
 
     def __init__(self, message=None):
 
-        message = 'This feature is not implemented yet.' if not message else message
+        message = "This feature is not implemented yet." if not message else message
 
         super(CluNotImplemented, self).__init__(message)
 
@@ -46,14 +51,17 @@ class CommandParserError(CluError):
 
 class CluBaseWarning(Warning):
     """Base warning for Clu."""
+
     pass
 
 
 class CluWarning(UserWarning, CluBaseWarning):
     """The primary warning class."""
+
     pass
 
 
 class CluDeprecationWarning(CluBaseWarning):
     """A warning for deprecated features."""
+
     pass
